# Seizhooks
 https://pypi.org/project/seizhooks
 https://discord.gg/wyUuYr9DEN
 https://github.com/seized0/seizhooks

 Seizhooks is a simple lib using discord api to interact with webhook
 Made by uhq.s

# REQUIREMENTS 

pip install requests
pip install colorama

# USING




Made with ❤️
By uhq.s

